<?php

// General: Start function create Google for Jobs code
function createGfjCode($vacancyOuid, $vacancyLanguage, $gfjHiringOrganizationLogo, $websiteName, $websiteUrl, $createOwsSession) {
	global $owsEndpoint, $owsApiKey, $sessionToken, $request, $response;

	// Include: Include OWS credentials ($owsEndpoint, $owsApiKey)
	include("OWS_CREDENTIALS_FILE_PATH");

	// Check input data: Die script & show error in case of incorrect OWS API key format
	if(!preg_match("/^[a-zA-Z0-9+=\/]{56}$/", $owsApiKey)) {
		die("<!-- Error #1. Incorrect OWS API key format. Not able to generate Google for Jobs code. -->");
	}

	// Check input data: Die script & show error in case of incorrect vacancy OUID format
	if(!preg_match("/^[a-zA-Z0-9_-]{16}$/", $vacancyOuid)) {
		die("<!-- Error #2. Incorrect vacancy OUID format. Not able to generate Google for Jobs code. -->");
	}

	// Check input data: Die script & show error in case of incorrect vacancy language format
	if(!preg_match("/^[a-z]{2}$/", $vacancyLanguage)) {
		die("<!-- Error #3. Incorrect vacancy language format '$vacancyLanguage'. Not able to generate Google for Jobs code. -->");
	}

	// Function: Send OWS request
	function sendOwsRequest() {
		global $request, $owsEndpoint, $response;
		$requestJson = json_encode($request);
		$curl = curl_init();
		curl_setopt($curl, CURLOPT_URL, $owsEndpoint);
		curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
		curl_setopt($curl, CURLOPT_POST, 1);
		curl_setopt($curl, CURLOPT_POSTFIELDS,$requestJson);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
		$responseJson  = curl_exec($curl);
		$response = json_decode($responseJson, true);
		curl_close($curl);
	}

	// Function: End OWS session
	function endOwsSession() {
		global $sessionToken, $request, $owsEndpoint, $response;
		$request = [
			'jsonrpc'=>'2.0',
			'method'=>'logout',
			'params'=>[
				$sessionToken
				],
			'id'=>1,
		];
		sendOwsRequest();
	}

	// Retrieve session token: Start follow up actions if OWS session needs to be created
	if($createOwsSession == true) {

		// Retrieve session token: Create OWS request
		$request = [
			'jsonrpc'=>'2.0',
			'method'=>'loginByUid',
			'params'=>[
				$owsApiKey
				],
			'id'=>1,
		];

		// Retrieve session token: Send OWS request
		sendOwsRequest();

		// Retrieve session token: Die script & show error in case of invalid OWS API key
		if($response['result'] == false) {
			die("<!-- Error #4. Invalid OWS API key. Not able to generate Google for Jobs code. -->");
		}

		// Retrieve session token: Declare variables
		$sessionToken = $response['result'];

	// Retrieve session token: End follow up actions if OWS session needs to be created
	}

	// Retrieve client data: Create OWS request
	$request = [
		'jsonrpc'=>'2.0',
		'method'=>'check',
		'params'=>[
			$sessionToken
			],
		'id'=>1,
	];

	// Retrieve client data: Send OWS request
	sendOwsRequest();

	// Retrieve client data: Die script & show error in case of invalid session
	if($response['result'] == false) {
		die("<!-- Error #5. Invalid session. Not able to generate Google for Jobs code. -->");
	}

	// Retrieve client data: Declare variables
	$clientId = $response['result']['clientId'];
	$clientName = $response['result']['client'];

	// Retrieve Google for Jobs main mapping: Create OWS request
	$request = [
		'jsonrpc'=>'2.0',
		'method'=>'Otys.Services.GoogleForJobsService.getDataStructure',
		'params'=>[
			$sessionToken,
			$clientId
			],
		'id'=>1,
	];

	// Retrieve Google for Jobs main mapping: Send OWS request
	sendOwsRequest();

	// Retrieve Google for Jobs main mapping: Die script & show error in case of no permission for main mapping
	if($response['error']) {
		if($createOwsSession == true) {
			endOwsSession();
		}
		die ("<!-- Error #6. No permissions for main mapping. Not able to generate Google for Jobs code. -->");
	}

	// Retrieve Google for Jobs main mapping: Declare variables
	$gfjEnabled = $response['result']['enable_google_for_jobs'];
	$gfjFieldTitle = $response['result']['savedMappings']['title'];
	$gfjFieldDescription = $response['result']['savedMappings']['description'];
	$gfjFieldIdentifierName = $response['result']['savedMappings']['identifier___name'];
	$gfjFieldIdentifierValue = $response['result']['savedMappings']['identifier___value'];
	$gfjFieldDatePosted = $response['result']['savedMappings']['datePosted'];
	$gfjFieldValidThrough = $response['result']['savedMappings']['validThrough'];
	$gfjFieldEmploymentType = $response['result']['savedMappings']['employmentType'];
	$gfjFieldHiringOrganizationName = $response['result']['savedMappings']['hiringOrganization___name'];
	$gfjFieldHiringOrganizationSameAs = $response['result']['savedMappings']['hiringOrganization___sameAs'];
	$gfjFieldCustomerLogo = $response['result']['savedMappings']['hiringOrganization___logo'];
	$gfjFieldStreetAddress = $response['result']['savedMappings']['jobLocation___address___streetAddress'];
	$gfjFieldAddressLocality = $response['result']['savedMappings']['jobLocation___address___addressLocality'];
	$gfjFieldAddressRegion = $response['result']['savedMappings']['jobLocation___address___addressRegion'];
	$gfjFieldPostalCode = $response['result']['savedMappings']['jobLocation___address___postalCode'];
	$gfjFieldAddressCountry = $response['result']['savedMappings']['jobLocation___address___addressCountry'];
	$gfjFieldBaseSalaryCurrency = $response['result']['savedMappings']['baseSalary___currency'];
	$gfjFieldBaseSalaryValueValue = $response['result']['savedMappings']['baseSalary___value___value'];
	$gfjFieldBaseSalaryValueUnitText = $response['result']['savedMappings']['baseSalary___value___unitText'];

	// Retrieve Google for Jobs employment type mapping: Create OWS request
	$request = [
		'jsonrpc'=>'2.0',
		'method'=>'Otys.Services.GoogleForJobsService.getEmploymentTypeMappings',
		'params'=>[
			$sessionToken,
			$clientId
			],
		'id'=>1,
	];

	// Retrieve Google for Jobs employment type mapping: Send OWS request
	sendOwsRequest();

	// Retrieve Google for Jobs sub mapping: Die script & show error in case of no permission for sub mapping
	if($response['error']) {
		if($createOwsSession == true) {
			endOwsSession();
		}
		die ("<!-- Error #7. No permissions for sub mapping. Not able to generate Google for Jobs code. -->");
	}

	// Retrieve Google for Jobs employment type mapping: Declare variables
	$gfjFieldEmploymentTypes = array();
	foreach($response['result']['mappedValues'] as $key => $value) {
		array_push($gfjFieldEmploymentTypes, array(
			'valueOtys' => $key,
			'ValueGfj' => $value
		));
	}

	// Create Google for Jobs code: Start follow up actions if Google for Jobs is enabled
	if($gfjEnabled == true) {

		// Set content language: Create OWS request
		$request = [
			'jsonrpc'=>'2.0',
			'method'=>'Otys.Services.VacancyService.setLanguage',
			'params'=>[
				$sessionToken,
				$vacancyLanguage
				],
			'id'=>1,
		];

		// Set content language: Send OWS request
		sendOwsRequest();
		
		// Retrieve vacancy data: Create OWS request
		$request = [
			'jsonrpc'=>'2.0',
			'method'=>'Otys.Services.VacancyService.getDetail',
			'params'=>[
				$sessionToken,
				$vacancyOuid,
				array(
					"entryDateTime"=>1,
					"externalReferenceNr"=>1,
					"location"=>1,
					"locationAddress"=>1,
					"locationCity"=>1,
					"locationCountryCode"=>1,
					"locationPostcode"=>1,
					"locationState"=>1,
					"matchCriteria_1"=>1,
					"matchCriteria_2"=>1,
					"matchCriteria_3"=>1,
					"matchCriteria_4"=>1,
					"matchCriteria_5"=>1,
					"matchCriteria_6"=>1,
					"matchCriteria_7"=>1,
					"matchCriteria_8"=>1,
					"matchCriteria_9"=>1,
					"matchCriteria_10"=>1,
					"matchCriteria_11"=>1,
					"matchCriteria_12"=>1,
					"matchCriteria_13"=>1,
					"matchCriteria_14"=>1,
					"matchCriteria_15"=>1,
					"matchCriteria_16"=>1,
					"matchCriteria_17"=>1,
					"matchCriteria_18"=>1,
					"publicationEndDate"=>1,
					"publicationFirstDate"=>1,
					"publicationStartDate"=>1,
					"referenceNr"=>1,
					"relation"=>1,
					"relationId"=>1,
					"salaryCurrency"=>1,
					"salaryUnit"=>1,
					"salaryValue"=>1,
					"textField_companyCulture"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_companyProfile"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_description"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra1"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra2"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra3"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra4"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra5"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra6"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra7"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra8"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra9"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_extra10"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_requirements"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_salary"=>array(
						"title"=>1,
						"text"=>1,
					),
					"textField_summary"=>array(
						"title"=>1,
						"text"=>1,
					),
					"title"=>1,
				),
			],
			'id'=>1,
		];

		// Retrieve vacancy data: Send OWS request
		sendOwsRequest();

		// Retrieve session token: Die script & show error in case of incorrect vacancy OUID
		if($response['result'] == false) {
			if($createOwsSession == true) {
				endOwsSession();
			}
			die ("<!-- Error #8. Incorrect vacancy OUID. Not able to generate Google for Jobs code. -->");
		}
		
		// Retrieve vacancy data: Declare variables
		$vacancyEntryDateTime = $response['result']['entryDateTime'];
		$vacancyExternalReferenceNr = $response['result']['externalReferenceNr'];
		$vacancyLocation = $response['result']['location'];
		$vacancyLocationAddress = $response['result']['locationAddress'];
		$vacancyLocationCity = $response['result']['locationCity'];
		$vacancyLocationCountryCode = $response['result']['locationCountryCode'];
		$vacancyLocationPostcode = $response['result']['locationPostcode'];
		$vacancyLocationState = $response['result']['locationState'];
		$vacancyMatchCriteria1 = $response['result']['matchCriteria_1'];
		$vacancyMatchCriteria2 = $response['result']['matchCriteria_2'];
		$vacancyMatchCriteria3 = $response['result']['matchCriteria_3'];
		$vacancyMatchCriteria4 = $response['result']['matchCriteria_4'];
		$vacancyMatchCriteria5 = $response['result']['matchCriteria_5'];
		$vacancyMatchCriteria6 = $response['result']['matchCriteria_6'];
		$vacancyMatchCriteria7 = $response['result']['matchCriteria_7'];
		$vacancyMatchCriteria8 = $response['result']['matchCriteria_8'];
		$vacancyMatchCriteria9 = $response['result']['matchCriteria_9'];
		$vacancyMatchCriteria10 = $response['result']['matchCriteria_10'];
		$vacancyMatchCriteria11 = $response['result']['matchCriteria_11'];
		$vacancyMatchCriteria12 = $response['result']['matchCriteria_12'];
		$vacancyMatchCriteria13 = $response['result']['matchCriteria_13'];
		$vacancyMatchCriteria14 = $response['result']['matchCriteria_14'];
		$vacancyMatchCriteria15 = $response['result']['matchCriteria_15'];
		$vacancyMatchCriteria16 = $response['result']['matchCriteria_16'];
		$vacancyMatchCriteria17 = $response['result']['matchCriteria_17'];
		$vacancyMatchCriteria18 = $response['result']['matchCriteria_18'];
		$vacancyPublicationEndDate = $response['result']['publicationEndDate'];
		$vacancyPublicationFirstDate = $response['result']['publicationFirstDate'];
		$vacancyPublicationStartDate = $response['result']['publicationStartDate'];
		$vacancyRefernceNr = $response['result']['referenceNr'];
		$vacancyRelation = $response['result']['relation'];
		$vacancyRelationId = $response['result']['relationId'];
		$vacancySalaryCurrency = $response['result']['salaryCurrency'];
		$vacancySalaryUnit = $response['result']['salaryUnit'];
		$vacancySalaryValue = $response['result']['salaryValue'];
		$vacancyTextFieldCompanyCultureTitle = $response['result']['textField_companyCulture']['title'];
		$vacancyTextFieldCompanyCultureText = $response['result']['textField_companyCulture']['text'];
		$vacancyTextFieldCompanyProfileTitle = $response['result']['textField_companyProfile']['title'];
		$vacancyTextFieldCompanyProfileText = $response['result']['textField_companyProfile']['text'];
		$vacancyTextFieldDescriptionTitle = $response['result']['textField_description']['title'];
		$vacancyTextFieldDescriptionText = $response['result']['textField_description']['text'];
		$vacancyTextFieldExtra1Title = $response['result']['textField_extra1']['title'];
		$vacancyTextFieldExtra1Text = $response['result']['textField_extra1']['text'];
		$vacancyTextFieldExtra2Title = $response['result']['textField_extra2']['title'];
		$vacancyTextFieldExtra2Text = $response['result']['textField_extra2']['text'];
		$vacancyTextFieldExtra3Title = $response['result']['textField_extra3']['title'];
		$vacancyTextFieldExtra3Text = $response['result']['textField_extra3']['text'];
		$vacancyTextFieldExtra4Title = $response['result']['textField_extra4']['title'];
		$vacancyTextFieldExtra4Text = $response['result']['textField_extra4']['text'];
		$vacancyTextFieldExtra5Title = $response['result']['textField_extra5']['title'];
		$vacancyTextFieldExtra5Text = $response['result']['textField_extra5']['text'];
		$vacancyTextFieldExtra6Title = $response['result']['textField_extra6']['title'];
		$vacancyTextFieldExtra6Text = $response['result']['textField_extra6']['text'];
		$vacancyTextFieldExtra7Title = $response['result']['textField_extra7']['title'];
		$vacancyTextFieldExtra7Text = $response['result']['textField_extra7']['text'];
		$vacancyTextFieldExtra8Title = $response['result']['textField_extra8']['title'];
		$vacancyTextFieldExtra8Text = $response['result']['textField_extra8']['text'];
		$vacancyTextFieldExtra9Title = $response['result']['textField_extra9']['title'];
		$vacancyTextFieldExtra9Text = $response['result']['textField_extra9']['text'];
		$vacancyTextFieldExtra10Title = $response['result']['textField_extra10']['title'];
		$vacancyTextFieldExtra10Text = $response['result']['textField_extra10']['text'];
		$vacancyTextFieldRequirementsTitle = $response['result']['textField_requirements']['title'];
		$vacancyTextFieldRequirementsText = $response['result']['textField_requirements']['text'];
		$vacancyTextFieldSalaryTitle = $response['result']['textField_salary']['title'];
		$vacancyTextFieldSalaryText = $response['result']['textField_salary']['text'];
		$vacancyTextFieldSummaryTitle = $response['result']['textField_summary']['title'];
		$vacancyTextFieldSummaryText = $response['result']['textField_summary']['text'];
		$vacancyTitle = $response['result']['title'];

		// Retrieve vacancy text field data: Create OWS request
		$request = [
			'jsonrpc'=>'2.0',
			'method'=>'Otys.Services.VacancyTextFieldService.getList',
			'params'=>[
				$sessionToken,
			],
			'id'=>1,
		];

		// Retrieve vacancy text field data: Send OWS request
		sendOwsRequest();
		
		// Retrieve vacancy text field data: Die script & show error in case of no permissions for retrieving vacancy texts
		if($response['error']) {
			if($createOwsSession == true) {
				endOwsSession();
			}
			die ("<!-- Error #9. No permissions for retrieving vacancy texts. Not able to generate Google for Jobs code. -->");
		}

		// Retrieve vacancy text field data: Create array
		$vacancyTextFields = array();
		foreach($response['result'] as $vacancyTextField) {
			$vacancyTextFieldRank = $vacancyTextField['rank'];
			$vacancyTextFieldField = $vacancyTextField['field'];
			$vacancyTextFieldPublished = $vacancyTextField['published'];
			array_push($vacancyTextFields, array(
				'rank' => $vacancyTextFieldRank,
				'field' => $vacancyTextFieldField,
				'published' => $vacancyTextFieldPublished
			));
		}

		// Retrieve vacancy text field data: Create all texts variable
		foreach($vacancyTextFields as $vacancyTextField) {
			if($vacancyTextField['field'] == 'bedrcultuur') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldCompanyCultureText) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldCompanyCultureTitle</h2>$vacancyTextFieldCompanyCultureText";
				}
			} elseif($vacancyTextField['field'] == 'bedrprofiel') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldCompanyProfileText) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldCompanyProfileTitle</h2>$vacancyTextFieldCompanyProfileText";
				}
			} elseif($vacancyTextField['field'] == 'chapo') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldDescriptionText) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldDescriptionTitle</h2>$vacancyTextFieldDescriptionText";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_01') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra1Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra1Title</h2>$vacancyTextFieldExtra1Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_02') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra2Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra2Title</h2>$vacancyTextFieldExtra2Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_03') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra3Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra3Title</h2>$vacancyTextFieldExtra3Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_04') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra4Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra4Title</h2>$vacancyTextFieldExtra4Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_05') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra5Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra5Title</h2>$vacancyTextFieldExtra5Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_06') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra6Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra6Title</h2>$vacancyTextFieldExtra6Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_07') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra7Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra7Title</h2>$vacancyTextFieldExtra7Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_08') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra8Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra8Title</h2>$vacancyTextFieldExtra8Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_09') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra9Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra9Title</h2>$vacancyTextFieldExtra9Text";
				}
			} elseif($vacancyTextField['field'] == 'extra_fld_10') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldExtra10Text) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldExtra10Title</h2>$vacancyTextFieldExtra10Text";
				}
			} elseif($vacancyTextField['field'] == 'functiee') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldRequirementsText) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldRequirementsTitle</h2>$vacancyTextFieldRequirementsText";
				}
			} elseif($vacancyTextField['field'] == 'functieo') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldSalaryText) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldSalaryTitle</h2>$vacancyTextFieldSalaryText";
				}
			} elseif($vacancyTextField['field'] == 'sal_o') {
				if($vacancyTextField['published'] == true && $vacancyTextFieldSummaryText) {
					$vacancyAllTexts .= "<h2>$vacancyTextFieldSummaryTitle</h2>$vacancyTextFieldSummaryText";
				}
			}
		}
		$vacancyAllTexts = str_replace(array("\r", "\n"), '', $vacancyAllTexts);
		
		// Retrieve relation data: Start follow up actions if vacancy is linked to relation
		if($vacancyRelationId) {

			// Retrieve relation data: Create OWS request
			$request = [
				'jsonrpc'=>'2.0',
				'method'=>'Otys.Services.RelationService.getDetail',
				'params'=>[
					$sessionToken,
					$vacancyRelationId,
					array(
						"website"=>1,
					),
				],
				'id'=>1,
			];

			// Retrieve relation data: Send OWS request
			sendOwsRequest();
			
			// Retrieve relation data: Declare variables
			$relationWebsite = $response['result']['website'];

		// Retrieve relation data: End follow up actions if vacancy is linked to relation
		}

		// Retrieve directApply property setting: Create OWS request
		$request = [
			'jsonrpc'=>'2.0',
			'method'=>'Otys.Services.CsmService.getValue',
			'params'=>[
				$sessionToken,
				"SE3321",
				$clientId,
				0,
				0
			],
			'id'=>1,
		];

		// Retrieve directApply property setting: Send OWS request
		sendOwsRequest();

		// Retrieve directApply property setting: Die script & show error in case of no permissions for retrieving directApply property setting
		if($response['error']) {
			if($createOwsSession == true) {
				endOwsSession();
			}
			die ("<!-- Error #10. No permissions for retrieving directApply property setting. Not able to generate Google for Jobs code. -->");
		}
		
		// Retrieve relation data: Declare variables
		if($response['result']['value'] == 1) {
			$gfjDirectApply = 'true';
		} elseif($response['result']['value'] == 0) {
			$gfjDirectApply = 'false';
		}

		// Create Google for Jobs code: Set Google for Jobs field 'datePosted'
		if($gfjFieldDatePosted == 'otys_recruit.vacaturebank.publiceer_date') {
			$gfjDatePosted = date("Y-m-d", strtotime($vacancyPublicationFirstDate));
		} elseif($gfjFieldDatePosted == 'otys_recruit.vacaturebank.invoerdatum') {
			$gfjDatePosted = date("Y-m-d", strtotime($vacancyEntryDateTime));
		} elseif($gfjFieldDatePosted == 'otys_recruit.vacaturebank.public_publish_date') {
			$gfjDatePosted = date("Y-m-d", strtotime($vacancyPublicationStartDate));
		} else {
			$gfjDatePosted = date("Y-m-d", strtotime($vacancyPublicationFirstDate));
		}

		// Create Google for Jobs code: Set Google for Jobs field 'hiringOrganization.name'
		if($gfjFieldHiringOrganizationName == 'otys_klanten.klanten.klant') {
			$gfjHiringOrganizationName = $clientName;
		} elseif($gfjFieldHiringOrganizationName == 'otys_klanten.websites.Name') {
			$gfjHiringOrganizationName = $websiteName;
		} elseif($gfjFieldHiringOrganizationName == 'otys_recruit.werkgevers.werkgever') {
			$gfjHiringOrganizationName = $vacancyRelation;
		} else {
			$gfjHiringOrganizationName = $clientName;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'hiringOrganization.sameAs'
		if($gfjFieldHiringOrganizationSameAs == 'otys_klanten.websites.Website') {
			$gfjHiringOrganizationSameAs = $websiteUrl;
		} elseif($gfjFieldHiringOrganizationSameAs == 'otys_recruit.werkgevers.wg_website') {
			$gfjHiringOrganizationSameAs = $relationWebsite;
		} else {
			$gfjHiringOrganizationSameAs = $relationWebsite;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'jobLocation.address.streetAddress'
		if($gfjFieldStreetAddress == 'otys_recruit.vacaturebank.address') {
			$gfjJobLocationAddressStreetAddress = $vacancyLocationAddress;
		} else {
			$gfjJobLocationAddressStreetAddress = $vacancyLocationAddress;
		}
		
		// Create Google for Jobs code: Set Google for Jobs field 'jobLocation.address.addressLocality'
		if($gfjFieldAddressLocality == 'otys_recruit.vacaturebank.locatie') {
			$gfjJobLocationAddressAddressLocality = $vacancyLocation;
		} elseif($gfjFieldAddressLocality == 'otys_recruit.vacaturebank.city') {
			$gfjJobLocationAddressAddressLocality = $vacancyLocationCity;
		} else {
			$gfjJobLocationAddressAddressLocality = $vacancyLocation;
		}
		
		// Create Google for Jobs code: Set Google for Jobs field 'jobLocation.address.addressRegion'
		if($gfjFieldAddressRegion == 'otys_recruit.vacaturebank.state') {
			$gfjJobLocationAddressRegion = $vacancyLocationState;
		} else {
			$gfjJobLocationAddressRegion = $vacancyLocationState;
		}
		
		// Create Google for Jobs code: Set Google for Jobs field 'jobLocation.address.postalCode'
		if($gfjFieldPostalCode == 'otys_recruit.vacaturebank.zipcode') {
			$gfjJobLocationAddressPostalCode = $vacancyLocationPostcode;
		} else {
			$gfjJobLocationAddressPostalCode = $vacancyLocationPostcode;
		}
		
		// Create Google for Jobs code: Set Google for Jobs field 'jobLocation.address.addressCountry'
		if($gfjFieldAddressCountry == 'otys_recruit.vacaturebank.country_code') {
			$gfjJobLocationAddressAddressCountry = $vacancyLocationCountryCode;
		} else {
			$gfjJobLocationAddressAddressCountry = $vacancyLocationCountryCode;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'title'
		if($gfjFieldTitle == 'otys_recruit.vacaturebank.functie_o') {
			$gfjTitle = $vacancyTitle;
		} else {
			$gfjTitle = $vacancyTitle;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'baseSalary.currency'
		if($gfjFieldBaseSalaryCurrency == 'otys_recruit.vacaturebank.extra_field_salary_currency') {
			$gfjBaseSalaryCurrency = $vacancySalaryCurrency;
		} else {
			$gfjBaseSalaryCurrency = $vacancySalaryCurrency;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'baseSalary.value.value'
		if($gfjFieldBaseSalaryValueValue == 'otys_recruit.vacaturebank.extra_field_salary_value') {
			$gfjFieldBaseSalaryValueValue = $vacancySalaryValue;
		} else {
			$gfjFieldBaseSalaryValueValue = $vacancySalaryValue;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'baseSalary.value.unitText'
		if($gfjFieldBaseSalaryValueUnitText == 'otys_recruit.vacaturebank.extra_field_salary_unit') {
			$gfjBaseSalaryValueUnitText = strtoupper($vacancySalaryUnit);
		} else {
			$gfjBaseSalaryValueUnitText = strtoupper($vacancySalaryUnit);
		}

		// Create Google for Jobs code: Set Google for Jobs field 'identifier.name'
		if($gfjFieldIdentifierName == 'otys_klanten.klanten.klant') {
			$gfjIdentifierName = $clientName;
		} elseif($gfjFieldIdentifierName == 'otys_klanten.websites.Name') {
			$gfjIdentifierName = $websiteName;
		} elseif($gfjFieldIdentifierName == 'otys_recruit.werkgevers.werkgever') {
			$gfjIdentifierName = $response['result']['relation'];
		} else {
			$gfjIdentifierName = $clientName;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'identifier.value'
		if($gfjFieldIdentifierValue == 'otys_recruit.vacaturebank.external_ref_nr') {
			$gfjIdentifierValue = $vacancyExternalReferenceNr;
		} elseif($gfjFieldIdentifierValue == 'otys_recruit.vacaturebank.ref_nr_varchar') {
			$gfjIdentifierValue = $vacancyRefernceNr;
		} else {
			$gfjIdentifierValue = $vacancyRefernceNr;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'validThrough'
		if($gfjFieldValidThrough == 'otys_recruit.vacaturebank.public_end_date') {
			$gfjValidThrough = date("Y-m-d", strtotime($vacancyPublicationEndDate));
		} else {
			$gfjValidThrough = date("Y-m-d", strtotime($vacancyPublicationEndDate));
		}

		// Create Google for Jobs code: Set Google for Jobs field 'description'
		if($gfjFieldValidThrough == 'otys_recruit.vacaturebank.allTexts') {
			$gfjDescription = $vacancyAllTexts;
		} else {
			$gfjDescription = $vacancyAllTexts;
		}

		// Create Google for Jobs code: Set Google for Jobs field 'employmentType'
		if($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.branche') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/1_/', '', key($vacancyMatchCriteria1))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.bedrcategorie') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/2_/', '', key($vacancyMatchCriteria2))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.verzekering') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/3_/', '', key($vacancyMatchCriteria3))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.functienaam') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/4_/', '', key($vacancyMatchCriteria4))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.dienstvb') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/5_/', '', key($vacancyMatchCriteria5))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.functiegr') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/6_/', '', key($vacancyMatchCriteria6))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.salaris') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/7_/', '', key($vacancyMatchCriteria7))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.gewuren') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/8_/', '', key($vacancyMatchCriteria8))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.opleidr') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/9_/', '', key($vacancyMatchCriteria9))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.opleidn') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/10_/', '', key($vacancyMatchCriteria10))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.wervaring') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/11_/', '', key($vacancyMatchCriteria11))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.regio') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/12_/', '', key($vacancyMatchCriteria12))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.beoordeling') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/13_/', '', key($vacancyMatchCriteria13))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.custom_crit_data_1') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/14_/', '', key($vacancyMatchCriteria14))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.custom_crit_data_2') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/15_/', '', key($vacancyMatchCriteria15))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.custom_crit_data_3') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/16_/', '', key($vacancyMatchCriteria16))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.custom_crit_data_4') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/17_/', '', key($vacancyMatchCriteria17))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} elseif($gfjFieldEmploymentType == 'otys_recruit.vacaturebank.custom_crit_data_5') {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/18_/', '', key($vacancyMatchCriteria18))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		} else {
			foreach($gfjFieldEmploymentTypes as $gfjFieldEmploymentType) {
				if($gfjFieldEmploymentType['valueOtys'] == preg_replace('/5_/', '', key($vacancyMatchCriteria5))) {
					$gfjEmploymentType = $gfjFieldEmploymentType['ValueGfj'];
				}
			}
		}

		// Create Google for Jobs code: Create array
		$gfjArray = array(
			"@context"=>"https://schema.org/",
			"@type"=>"JobPosting",
			"title"=>"$gfjTitle",
			"description"=>"$gfjDescription",
			"identifier"=>array(
				"@type"=>"PropertyValue",
				"name"=>"$gfjIdentifierName",
				"value"=>"$gfjIdentifierValue",
			),
			"datePosted"=>"$gfjDatePosted",
			"validThrough"=>"$gfjValidThrough",
			"directApply"=>$gfjDirectApply,
			"employmentType"=>"$gfjEmploymentType",
			"hiringOrganization"=>array(
				"@type"=>"Organization",
				"name"=>"$gfjHiringOrganizationName",
				"sameAs"=>"$gfjHiringOrganizationSameAs",
				"logo"=>"$gfjHiringOrganizationLogo",
			),
			"jobLocation"=>array(
				"@type"=>"Place",
				"address"=>array(
					"@type"=>"PostalAddress",
					"streetAddress"=>"$gfjJobLocationAddressStreetAddress",
					"addressLocality"=>"$gfjJobLocationAddressAddressLocality",
					"addressRegion"=>"$gfjJobLocationAddressRegion",
					"postalCode"=>"$gfjJobLocationAddressPostalCode",
					"addressCountry"=>"$gfjJobLocationAddressAddressCountry",
				),
			),
			"baseSalary"=>array(
				"@type"=>"MonetaryAmount",
				"currency"=>"$gfjBaseSalaryCurrency",
				"value"=>array(
					"@type"=>"QuantitativeValue",
					"value"=>$gfjFieldBaseSalaryValueValue,
					"unitText"=>"$gfjBaseSalaryValueUnitText",
				),
			),
		);

		// Create Google for Jobs code: Remove empty elements from array
		if(!$gfjArray['title']) {
			unset($gfjArray['title']);
		}
		if(!$gfjArray['description']) {
			unset($gfjArray['description']);
		}
		if(!$gfjArray['identifier']['name']) {
			unset($gfjArray['identifier']['name']);
		}
		if(!$gfjArray['identifier']['value']) {
			unset($gfjArray['identifier']['value']);
		}
		if(!$gfjArray['datePosted'] || $gfjArray['datePosted'] == '1970-01-01') {
			unset($gfjArray['datePosted']);
		}
		if(!$gfjArray['validThrough'] || $gfjArray['validThrough'] == '1970-01-01') {
			unset($gfjArray['validThrough']);
		}
		if(!$gfjArray['directApply']) {
			unset($gfjArray['directApply']);
		}
		if(!$gfjArray['employmentType']) {
			unset($gfjArray['employmentType']);
		}
		if(!$gfjArray['hiringOrganization']['name']) {
			unset($gfjArray['hiringOrganization']['name']);
		}
		if(!$gfjArray['hiringOrganization']['sameAs']) {
			unset($gfjArray['hiringOrganization']['sameAs']);
		}
		if(!$gfjArray['hiringOrganization']['logo']) {
			unset($gfjArray['hiringOrganization']['logo']);
		}
		if(!$gfjArray['jobLocation']['address']['streetAddress']) {
			unset($gfjArray['jobLocation']['address']['streetAddress']);
		}
		if(!$gfjArray['jobLocation']['address']['addressLocality']) {
			unset($gfjArray['jobLocation']['address']['addressLocality']);
		}
		if(!$gfjArray['jobLocation']['address']['addressRegion']) {
			unset($gfjArray['jobLocation']['address']['addressRegion']);
		}
		if(!$gfjArray['jobLocation']['address']['postalCode']) {
			unset($gfjArray['jobLocation']['address']['postalCode']);
		}
		if(!$gfjArray['jobLocation']['address']['addressCountry']) {
			unset($gfjArray['jobLocation']['address']['addressCountry']);
		}
		if(!$gfjArray['baseSalary']['currency']) {
			unset($gfjArray['baseSalary']['currency']);
		}
		if(!$gfjArray['baseSalary']['value']['value']) {
			unset($gfjArray['baseSalary']['value']['value']);
		}
		if(!$gfjArray['baseSalary']['value']['unitText']) {
			unset($gfjArray['baseSalary']['value']['unitText']);
		}
		
		// Create Google for Jobs code: Create JSON
		$gfjJson = json_encode($gfjArray);

		// Create Google for Jobs code: Create code
		$gfjCode = "<script type=\"application/ld+json\">$gfjJson</script>";

	// Create Google for Jobs code: End follow up actions if Google for Jobs is enabled
	};

	// End session: Start follow up actions if OWS session needs to be ended
	if($createOwsSession == true) {

		// End session: Create array request
		$request = [
			'jsonrpc'=>'2.0',
			'method'=>'logout',
			'params'=>[
				$sessionToken
				],
			'id'=>1,
		];

		// End session: Send OWS request
		sendOwsRequest();

	// End session: End follow up actions if OWS session needs to be ended
	}

	// General: Return Google for Jobs code
	return $gfjCode;

// General: End function create Google for Jobs code
}

?>